@@ -2,7 +2,7 @@ import datetime
 from django.db import models
 from django.contrib.contenttypes.models import ContentType
 from django.contrib.contenttypes import generic
-from managers import CallbackMapManager
+from callback.managers import CallbackMapManager
 
 
 class CallbackMap(models.Model):
